@@ -21,10 +21,10 @@ import typing
 import opentelemetry.sdk.util.instrumentation as otel_instrumentation
 import opentelemetry.sdk._logs._internal as _logs_internal
 
-from opentelemetry.exporter.otlp.proto.common._log_encoder import (
+from snowflake.telemetry._internal.opentelemetry.exporter.otlp.proto.common._log_encoder import (
     encode_logs,
 )
-from opentelemetry.proto.logs.v1.logs_pb2 import LogsData
+from snowflake.telemetry._internal.opentelemetry.proto.logs.v1.logs_marshaler import LogsData
 from opentelemetry.sdk.resources import Resource
 from opentelemetry.sdk._logs import export
 from opentelemetry.sdk import _logs
@@ -183,10 +183,10 @@ class _SnowflakeTelemetryLoggerProvider(_logs.LoggerProvider):
     """
 
     def get_logger(
-        self,
-        name: str,
-        version: types.Optional[str] = None,
-        schema_url: types.Optional[str] = None,
+            self, name: str,
+            version: types.Optional[str] = None,
+            schema_url: types.Optional[str] = None,
+            attributes: types.Optional[types.Attributes] = None,
     ) -> _logs.Logger:
         return _SnowflakeTelemetryLogger(
             Resource.get_empty(),
